:github_url:

.. _wineenv:

.. index::
	single: configuration
	triple: wine; python; environment
	module: wenv.EnvConfig

Configuration
=============

The class ``EnvConfig`` is meant to initialize :class:`wenv.Env`. For available configuration options, see :ref:`chapter on configuration parameters <parameters>`.

.. autoclass:: wenv.EnvConfig
    :members:
